path_from_search_map

Function path_from_search_map 

pub fn path_from_search_map(
    search_map: &SearchMap,
    start: Point,
) -> Option<Path>
Takes a result from dijkstra map and returns a best path from start to the goal set by the search map.

Returns None when start is not reachable from the goal set.

Panics

Panics when start is outside the search map.