pub struct SearchMap {
pub costs: Grid<Option<Cost>>,
pub reached_from: Grid<Option<Point>>,
}Expand description
Map structure used for holding movement costs and parent nodes.
Fields
costs: Grid<Option<Cost>>Cheapest known cost from each point to the goal set, or None when unreachable.
reached_from: Grid<Option<Point>>The next point toward a goal for each reachable point.